==> SyL-0.14.2.tar.gz: SyL/include/framework/Data/SyL_DataCmd.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_DataCmd.php,v 1.4 2007/07/29 08:54:59 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ޥɥ饤ǡݻ饹
 * 
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_DataCmd.php,v 1.4 2007/07/29 08:54:59 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_DataCmd extends SyL_Data
{
    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function SyL_DataCmd()
    {
        // ѥ᡼
        $args = $_SERVER['argv'];

        $i = 0;
        $tmp_arg = null;
        foreach ($args as $arg) {
            if (substr($arg, 0, 1) == '-') {
                if (strlen($arg) > 1) {
                    $tmp_arg = substr($arg, 1);
                    $value = $this->get($tmp_arg);
                    if ($value !== null) {
                        array_push($value, null);
                        $this->set($tmp_arg, $value);
                    } else {
                        $this->set($tmp_arg, array(null));
                    }
                }
            } else {
                if ($tmp_arg !== null) {
                    $value = $this->get($tmp_arg);
                    $value[count($value)-1] = $arg;
                    $this->set($tmp_arg, $value);
                    $tmp_arg = null;
                } else {
                    $this->set($i++, $arg);
                }
            }
        }
    }
}

?>

==> SyL-0.14.11.tar.gz: SyL/include/framework/Data/SyL_DataCmd.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_DataCmd.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ޥɥ饤ǡݻ饹
 * 
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_DataCmd.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_DataCmd extends SyL_Data
{
    /**
     * ϥѥ᡼򥻥å
     * 
     * @access protected
     */
    function initInputs()
    {
        // ѥ᡼
        $args = $_SERVER['argv'];

        $i = 0;
        $tmp_arg = null;
        foreach ($args as $arg) {
            if (substr($arg, 0, 1) == '-') {
                if (strlen($arg) > 1) {
                    $tmp_arg = substr($arg, 1);
                    $value = $this->get($tmp_arg);
                    if ($value !== null) {
                        array_push($value, null);
                        $this->set($tmp_arg, $value);
                    } else {
                        $this->set($tmp_arg, array(null));
                    }
                }
            } else {
                if ($tmp_arg !== null) {
                    $value = $this->get($tmp_arg);
                    $value[count($value)-1] = $arg;
                    $this->set($tmp_arg, $value);
                    $tmp_arg = null;
                } else {
                    $this->set($i++, $arg);
                }
            }
        }
    }

    /**
     * ǸŪ˥ѥ᡼᥽å
     * 
     * @access public
     * @return array ѥ᡼
     */
    function finalOutputs()
    {
        return null;
    }
}

?>
